import { __exports as alertRole } from '../../../../../../_virtual/alertRole.js';

var hasRequiredAlertRole;

function requireAlertRole () {
	if (hasRequiredAlertRole) return alertRole;
	hasRequiredAlertRole = 1;

	Object.defineProperty(alertRole, "__esModule", {
	  value: true
	});
	alertRole.default = undefined;
	var alertRole$1 = {
	  abstract: false,
	  accessibleNameRequired: false,
	  baseConcepts: [],
	  childrenPresentational: false,
	  nameFrom: ['author'],
	  prohibitedProps: [],
	  props: {
	    'aria-atomic': 'true',
	    'aria-live': 'assertive'
	  },
	  relatedConcepts: [{
	    concept: {
	      name: 'alert'
	    },
	    module: 'XForms'
	  }],
	  requireContextRole: [],
	  requiredContextRole: [],
	  requiredOwnedElements: [],
	  requiredProps: {},
	  superClass: [['roletype', 'structure', 'section']]
	};
	var _default = alertRole$1;
	alertRole.default = _default;
	return alertRole;
}

export { requireAlertRole as __require };
//# sourceMappingURL=alertRole.js.map
